[libcxx] r338093 - Implement <filesystem>
Eric Fiselier via cfe-commits
cfe-commits at lists.llvm.org
Thu Jul 26 20:07:10 PDT 2018
Copied: libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/path.factory.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.path/path.nonmember/path.factory.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/path.factory.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/path.factory.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.path/path.nonmember/path.factory.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.path/path.nonmember/path.factory.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/path.factory.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// template <class Source>
// path u8path(Source const&);
Copied: libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/path.io.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.path/path.nonmember/path.io.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/path.io.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/path.io.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.path/path.nonmember/path.io.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.path/path.nonmember/path.io.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/path.io.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// class path
Copied: libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/path.io.unicode_bug.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.path/path.nonmember/path.io.unicode_bug.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/path.io.unicode_bug.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/path.io.unicode_bug.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.path/path.nonmember/path.io.unicode_bug.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.path/path.nonmember/path.io.unicode_bug.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/path.io.unicode_bug.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// class path
Copied: libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/swap.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.path/path.nonmember/swap.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/swap.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/swap.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.path/path.nonmember/swap.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.path/path.nonmember/swap.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.path/path.nonmember/swap.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// void swap(path& lhs, path& rhs) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/class.path/synop.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.path/synop.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.path/synop.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.path/synop.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.path/synop.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.path/synop.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.path/synop.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// class path
Copied: libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/copy.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/copy.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/copy.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/copy.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/copy.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/copy.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/copy.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// class recursive_directory_iterator
Copied: libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/copy_assign.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/copy_assign.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/copy_assign.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/copy_assign.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/copy_assign.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/copy_assign.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/copy_assign.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// class recursive_directory_iterator
Copied: libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/ctor.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/ctor.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/ctor.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/ctor.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/ctor.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/ctor.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/ctor.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// class directory_iterator
Copied: libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/depth.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/depth.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/depth.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/depth.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/depth.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/depth.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/depth.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// class recursive_directory_iterator
Copied: libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/disable_recursion_pending.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/disable_recursion_pending.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/disable_recursion_pending.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/disable_recursion_pending.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/disable_recursion_pending.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/disable_recursion_pending.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/disable_recursion_pending.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// class recursive_directory_iterator
Copied: libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/increment.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/increment.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/increment.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/increment.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/increment.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/increment.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/increment.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// class recursive_directory_iterator
Copied: libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/move.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/move.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/move.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/move.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/move.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/move.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/move.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// class recursive_directory_iterator
Copied: libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/move_assign.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/move_assign.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/move_assign.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/move_assign.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/move_assign.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/move_assign.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/move_assign.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// class recursive_directory_iterator
Copied: libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/pop.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/pop.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/pop.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/pop.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/pop.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/pop.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/pop.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// class recursive_directory_iterator
Copied: libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/recursion_pending.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/recursion_pending.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/recursion_pending.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/recursion_pending.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/recursion_pending.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.members/recursion_pending.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.members/recursion_pending.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// class recursive_directory_iterator
Copied: libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.nonmembers/begin_end.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.nonmembers/begin_end.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.nonmembers/begin_end.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.nonmembers/begin_end.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.nonmembers/begin_end.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.rec.dir.itr/rec.dir.itr.nonmembers/begin_end.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/class.rec.dir.itr/rec.dir.itr.nonmembers/begin_end.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// class recursive_directory_iterator
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.enum/check_bitmask_types.hpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.enum/check_bitmask_types.hpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.enum/check_bitmask_types.hpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.enum/check_bitmask_types.hpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.enum/check_bitmask_types.hpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
(empty)
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.copy_options.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.copy_options.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.copy_options.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.copy_options.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.copy_options.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.copy_options.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.copy_options.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// enum class copy_options;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.directory_options.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.directory_options.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.directory_options.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.directory_options.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.directory_options.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.directory_options.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.directory_options.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// enum class directory_options;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.file_type.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.file_type.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.file_type.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.file_type.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.file_type.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.file_type.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.file_type.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// enum class file_type;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.path.format.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.path.format.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.path.format.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.path.format.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.path.format.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.path.format.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.path.format.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// class path;
// enum class format;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.perm_options.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.perm_options.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.perm_options.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.perm_options.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.perm_options.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.perm_options.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.perm_options.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// enum class perm_options;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.perms.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.perms.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.perms.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.perms.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.perms.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.enum/enum.perms.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.enum/enum.perms.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// enum class perms;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.error.report/tested_elsewhere.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.error.report/tested_elsewhere.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.error.report/tested_elsewhere.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.error.report/tested_elsewhere.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.error.report/tested_elsewhere.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
(empty)
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.filesystem.synopsis/file_time_type.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.filesystem.synopsis/file_time_type.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.filesystem.synopsis/file_time_type.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.filesystem.synopsis/file_time_type.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.filesystem.synopsis/file_time_type.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.filesystem.synopsis/file_time_type.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.filesystem.synopsis/file_time_type.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// typedef TrivialClock file_time_type;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.absolute/absolute.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.absolute/absolute.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.absolute/absolute.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.absolute/absolute.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.absolute/absolute.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.absolute/absolute.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.absolute/absolute.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// path absolute(const path& p, const path& base=current_path());
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.canonical/canonical.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.canonical/canonical.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.canonical/canonical.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.canonical/canonical.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.canonical/canonical.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.canonical/canonical.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.canonical/canonical.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// path canonical(const path& p);
// path canonical(const path& p, error_code& ec);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy/copy.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.copy/copy.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy/copy.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy/copy.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.copy/copy.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.copy/copy.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy/copy.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// void copy(const path& from, const path& to);
// void copy(const path& from, const path& to, error_code& ec);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy_file/copy_file.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.copy_file/copy_file.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy_file/copy_file.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy_file/copy_file.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.copy_file/copy_file.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.copy_file/copy_file.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy_file/copy_file.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool copy_file(const path& from, const path& to);
// bool copy_file(const path& from, const path& to, error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy_file/copy_file_large.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.copy_file/copy_file_large.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy_file/copy_file_large.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy_file/copy_file_large.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.copy_file/copy_file_large.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.copy_file/copy_file_large.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy_file/copy_file_large.pass.cpp Thu Jul 26 20:07:09 2018
@@ -10,7 +10,7 @@
// UNSUPPORTED: c++98, c++03
// REQUIRES: long_tests
-// <experimental/filesystem>
+// <filesystem>
// bool copy_file(const path& from, const path& to);
// bool copy_file(const path& from, const path& to, error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy_symlink/copy_symlink.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.copy_symlink/copy_symlink.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy_symlink/copy_symlink.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy_symlink/copy_symlink.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.copy_symlink/copy_symlink.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.copy_symlink/copy_symlink.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.copy_symlink/copy_symlink.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// void copy_symlink(const path& existing_symlink, const path& new_symlink);
// void copy_symlink(const path& existing_symlink, const path& new_symlink,
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directories/create_directories.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_directories/create_directories.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directories/create_directories.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directories/create_directories.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_directories/create_directories.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_directories/create_directories.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directories/create_directories.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool create_directories(const path& p);
// bool create_directories(const path& p, error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directory/create_directory.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_directory/create_directory.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directory/create_directory.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directory/create_directory.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_directory/create_directory.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_directory/create_directory.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directory/create_directory.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool create_directory(const path& p);
// bool create_directory(const path& p, error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directory/create_directory_with_attributes.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_directory/create_directory_with_attributes.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directory/create_directory_with_attributes.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directory/create_directory_with_attributes.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_directory/create_directory_with_attributes.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_directory/create_directory_with_attributes.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directory/create_directory_with_attributes.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool create_directory(const path& p, const path& attr);
// bool create_directory(const path& p, const path& attr, error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directory_symlink/create_directory_symlink.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_directory_symlink/create_directory_symlink.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directory_symlink/create_directory_symlink.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directory_symlink/create_directory_symlink.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_directory_symlink/create_directory_symlink.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_directory_symlink/create_directory_symlink.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_directory_symlink/create_directory_symlink.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// void create_directory_symlink(const path& existing_symlink, const path& new_symlink);
// void create_directory_symlink(const path& existing_symlink, const path& new_symlink,
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_hard_link/create_hard_link.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_hard_link/create_hard_link.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_hard_link/create_hard_link.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_hard_link/create_hard_link.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_hard_link/create_hard_link.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_hard_link/create_hard_link.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_hard_link/create_hard_link.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// void create_hard_link(const path& existing_symlink, const path& new_symlink);
// void create_hard_link(const path& existing_symlink, const path& new_symlink,
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_symlink/create_symlink.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_symlink/create_symlink.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_symlink/create_symlink.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_symlink/create_symlink.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_symlink/create_symlink.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.create_symlink/create_symlink.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.create_symlink/create_symlink.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// void create_symlink(const path& existing_symlink, const path& new_symlink);
// void create_symlink(const path& existing_symlink, const path& new_symlink,
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.current_path/current_path.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.current_path/current_path.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.current_path/current_path.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.current_path/current_path.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.current_path/current_path.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.current_path/current_path.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.current_path/current_path.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// path current_path();
// path current_path(error_code& ec);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.equivalent/equivalent.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.equivalent/equivalent.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.equivalent/equivalent.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.equivalent/equivalent.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.equivalent/equivalent.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.equivalent/equivalent.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.equivalent/equivalent.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool equivalent(path const& lhs, path const& rhs);
// bool equivalent(path const& lhs, path const& rhs, std::error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.exists/exists.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.exists/exists.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.exists/exists.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.exists/exists.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.exists/exists.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.exists/exists.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.exists/exists.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool exists(file_status s) noexcept
// bool exists(path const& p);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.file_size/file_size.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.file_size/file_size.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.file_size/file_size.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.file_size/file_size.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.file_size/file_size.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.file_size/file_size.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.file_size/file_size.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// uintmax_t file_size(const path& p);
// uintmax_t file_size(const path& p, std::error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.hard_lk_ct/hard_link_count.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.hard_lk_ct/hard_link_count.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.hard_lk_ct/hard_link_count.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.hard_lk_ct/hard_link_count.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.hard_lk_ct/hard_link_count.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.hard_lk_ct/hard_link_count.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.hard_lk_ct/hard_link_count.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// uintmax_t hard_link_count(const path& p);
// uintmax_t hard_link_count(const path& p, std::error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_block_file/is_block_file.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_block_file/is_block_file.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_block_file/is_block_file.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_block_file/is_block_file.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_block_file/is_block_file.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_block_file/is_block_file.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_block_file/is_block_file.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool is_block_file(file_status s) noexcept
// bool is_block_file(path const& p);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_char_file/is_character_file.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_char_file/is_character_file.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_char_file/is_character_file.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_char_file/is_character_file.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_char_file/is_character_file.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_char_file/is_character_file.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_char_file/is_character_file.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool is_character_file(file_status s) noexcept
// bool is_character_file(path const& p);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_directory/is_directory.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_directory/is_directory.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_directory/is_directory.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_directory/is_directory.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_directory/is_directory.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_directory/is_directory.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_directory/is_directory.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool is_directory(file_status s) noexcept
// bool is_directory(path const& p);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_empty/is_empty.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_empty/is_empty.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_empty/is_empty.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_empty/is_empty.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_empty/is_empty.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_empty/is_empty.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_empty/is_empty.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool is_empty(path const& p);
// bool is_empty(path const& p, std::error_code& ec);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_fifo/is_fifo.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_fifo/is_fifo.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_fifo/is_fifo.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_fifo/is_fifo.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_fifo/is_fifo.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_fifo/is_fifo.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_fifo/is_fifo.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool is_fifo(file_status s) noexcept
// bool is_fifo(path const& p);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_other/is_other.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_other/is_other.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_other/is_other.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_other/is_other.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_other/is_other.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_other/is_other.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_other/is_other.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool is_other(file_status s) noexcept
// bool is_other(path const& p);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_regular_file/is_regular_file.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_regular_file/is_regular_file.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_regular_file/is_regular_file.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_regular_file/is_regular_file.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_regular_file/is_regular_file.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_regular_file/is_regular_file.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_regular_file/is_regular_file.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool is_regular_file(file_status s) noexcept
// bool is_regular_file(path const& p);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_socket/is_socket.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_socket/is_socket.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_socket/is_socket.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_socket/is_socket.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_socket/is_socket.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_socket/is_socket.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_socket/is_socket.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool is_socket(file_status s) noexcept
// bool is_socket(path const& p);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_symlink/is_symlink.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_symlink/is_symlink.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_symlink/is_symlink.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_symlink/is_symlink.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_symlink/is_symlink.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.is_symlink/is_symlink.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.is_symlink/is_symlink.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool is_symlink(file_status s) noexcept
// bool is_symlink(path const& p);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.last_write_time/last_write_time.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.last_write_time/last_write_time.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.last_write_time/last_write_time.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.last_write_time/last_write_time.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.last_write_time/last_write_time.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.last_write_time/last_write_time.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.last_write_time/last_write_time.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// file_time_type last_write_time(const path& p);
// file_time_type last_write_time(const path& p, std::error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.permissions/permissions.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.permissions/permissions.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.permissions/permissions.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.permissions/permissions.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.permissions/permissions.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.permissions/permissions.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.permissions/permissions.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// void permissions(const path& p, perms prms,
// perm_options opts = perm_options::replace);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.proximate/proximate.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.proximate/proximate.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.proximate/proximate.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.proximate/proximate.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.proximate/proximate.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.proximate/proximate.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.proximate/proximate.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// path proximate(const path& p, error_code &ec)
// path proximate(const path& p, const path& base = current_path())
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.read_symlink/read_symlink.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.read_symlink/read_symlink.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.read_symlink/read_symlink.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.read_symlink/read_symlink.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.read_symlink/read_symlink.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.read_symlink/read_symlink.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.read_symlink/read_symlink.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// path read_symlink(const path& p);
// path read_symlink(const path& p, error_code& ec);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.relative/relative.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.relative/relative.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.relative/relative.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.relative/relative.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.relative/relative.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.relative/relative.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.relative/relative.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// path proximate(const path& p, error_code &ec)
// path proximate(const path& p, const path& base = current_path())
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.remove/remove.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.remove/remove.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.remove/remove.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.remove/remove.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.remove/remove.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.remove/remove.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.remove/remove.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool remove(const path& p);
// bool remove(const path& p, error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.remove_all/remove_all.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.remove_all/remove_all.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.remove_all/remove_all.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.remove_all/remove_all.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.remove_all/remove_all.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.remove_all/remove_all.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.remove_all/remove_all.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// uintmax_t remove_all(const path& p);
// uintmax_t remove_all(const path& p, error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.rename/rename.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.rename/rename.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.rename/rename.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.rename/rename.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.rename/rename.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.rename/rename.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.rename/rename.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// void rename(const path& old_p, const path& new_p);
// void rename(const path& old_p, const path& new_p, error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.resize_file/resize_file.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.resize_file/resize_file.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.resize_file/resize_file.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.resize_file/resize_file.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.resize_file/resize_file.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.resize_file/resize_file.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.resize_file/resize_file.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// void resize_file(const path& p, uintmax_t new_size);
// void resize_file(const path& p, uintmax_t new_size, error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.space/space.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.space/space.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.space/space.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.space/space.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.space/space.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.space/space.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.space/space.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// space_info space(const path& p);
// space_info space(const path& p, error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.status/status.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.status/status.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.status/status.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.status/status.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.status/status.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.status/status.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.status/status.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// file_status status(const path& p);
// file_status status(const path& p, error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.status_known/status_known.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.status_known/status_known.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.status_known/status_known.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.status_known/status_known.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.status_known/status_known.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.status_known/status_known.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.status_known/status_known.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// bool status_known(file_status s) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.symlink_status/symlink_status.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.symlink_status/symlink_status.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.symlink_status/symlink_status.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.symlink_status/symlink_status.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.symlink_status/symlink_status.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.symlink_status/symlink_status.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.symlink_status/symlink_status.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// file_status symlink_status(const path& p);
// file_status symlink_status(const path& p, error_code& ec) noexcept;
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.temp_dir_path/temp_directory_path.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.temp_dir_path/temp_directory_path.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.temp_dir_path/temp_directory_path.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.temp_dir_path/temp_directory_path.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.temp_dir_path/temp_directory_path.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.temp_dir_path/temp_directory_path.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.temp_dir_path/temp_directory_path.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// path temp_directory_path();
// path temp_directory_path(error_code& ec);
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.weakly_canonical/weakly_canonical.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.weakly_canonical/weakly_canonical.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.weakly_canonical/weakly_canonical.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.weakly_canonical/weakly_canonical.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.weakly_canonical/weakly_canonical.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/fs.op.funcs/fs.op.weakly_canonical/weakly_canonical.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.op.funcs/fs.op.weakly_canonical/weakly_canonical.pass.cpp Thu Jul 26 20:07:09 2018
@@ -9,7 +9,7 @@
// UNSUPPORTED: c++98, c++03
-// <experimental/filesystem>
+// <filesystem>
// path weakly_canonical(const path& p);
// path weakly_canonical(const path& p, error_code& ec);
Added: libcxx/trunk/test/std/input.output/filesystems/fs.req.macros/feature_macro.pass.cpp
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.req.macros/feature_macro.pass.cpp?rev=338093&view=auto
==============================================================================
--- libcxx/trunk/test/std/input.output/filesystems/fs.req.macros/feature_macro.pass.cpp (added)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.req.macros/feature_macro.pass.cpp Thu Jul 26 20:07:09 2018
@@ -0,0 +1,29 @@
+//===----------------------------------------------------------------------===//
+//
+// The LLVM Compiler Infrastructure
+//
+// This file is dual licensed under the MIT and the University of Illinois Open
+// Source Licenses. See LICENSE.TXT for details.
+//
+//===----------------------------------------------------------------------===//
+
+// <filesystem>
+
+// #define __cpp_lib_filesystem 201703L
+
+#include <filesystem>
+#include "test_macros.h"
+
+#if TEST_STD_VER >= 17
+#ifndef __cpp_lib_filesystem
+#error Filesystem feature test macro is not defined (__cpp_lib_filesystem)
+#elif __cpp_lib_filesystem != 201703L
+#error Filesystem feature test macro has an incorrect value (__cpp_lib_filesystem)
+#endif
+#else // TEST_STD_VER < 17
+#ifdef __cpp_lib_filesystem
+#error Filesystem feature test macro should not be defined before C++17
+#endif
+#endif
+
+int main() { }
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.req.namespace/namespace.fail.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.path/path.member/path.assign/braced_init.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.req.namespace/namespace.fail.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.req.namespace/namespace.fail.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.path/path.member/path.assign/braced_init.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/std/experimental/filesystem/class.path/path.member/path.assign/braced_init.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.req.namespace/namespace.fail.cpp Thu Jul 26 20:07:09 2018
@@ -7,25 +7,23 @@
//
//===----------------------------------------------------------------------===//
-// UNSUPPORTED: c++98, c++03
+// REQUIRES: c++98 || c++03 || c++11 || c++14
-// <experimental/filesystem>
+// <filesystem>
-// class path
-
-// path& operator=(path const&);
-
-#include "filesystem_include.hpp"
-#include <type_traits>
-#include <cassert>
+// namespace std::filesystem
+#include <filesystem>
#include "test_macros.h"
-#include "count_new.hpp"
+using namespace std::filesystem;
+
+#if TEST_STD_VER >= 11
+// expected-error at -3 {{no namespace named 'filesystem' in namespace 'std';}}
+#else
+// expected-error at -5 {{expected namespace name}}
+#endif
int main() {
- using namespace fs;
- path p("abc");
- p = {};
- assert(p.native() == "");
+
}
Copied: libcxx/trunk/test/std/input.output/filesystems/fs.req.namespace/namespace.pass.cpp (from r338006, libcxx/trunk/test/std/experimental/filesystem/class.path/path.member/path.assign/braced_init.pass.cpp)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/fs.req.namespace/namespace.pass.cpp?p2=libcxx/trunk/test/std/input.output/filesystems/fs.req.namespace/namespace.pass.cpp&p1=libcxx/trunk/test/std/experimental/filesystem/class.path/path.member/path.assign/braced_init.pass.cpp&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
--- libcxx/trunk/test/support/filesystem_include.hpp (original)
+++ libcxx/trunk/test/support/filesystem_include.hpp Thu Jul 26 20:07:09 2018
@@ -1,18 +1,13 @@
#ifndef TEST_SUPPORT_FILESYSTEM_INCLUDE_HPP
#define TEST_SUPPORT_FILESYSTEM_INCLUDE_HPP
-#include <ciso646>
-// Test against std::filesystem for STL's other than libc++
-#ifndef _LIBCPP_VERSION
-#define TEST_INCLUDE_STD_FILESYSTEM
-#endif
-
-#ifdef TEST_INCLUDE_STD_FILESYSTEM
#include <filesystem>
-namespace fs = std::filesystem;
+#include "test_macros.h"
+
+#if defined(_LIBCPP_VERSION) && TEST_STD_VER < 17
+namespace fs = std::__fs::filesystem;
#else
-#include <experimental/filesystem>
-namespace fs = std::experimental::filesystem;
+namespace fs = std::filesystem;
#endif
#endif
Modified: libcxx/trunk/utils/libcxx/test/config.py
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/utils/libcxx/test/config.py?rev=338093&r1=338092&r2=338093&view=diff
==============================================================================
--- libcxx/trunk/utils/libcxx/test/config.py (original)
+++ libcxx/trunk/utils/libcxx/test/config.py Thu Jul 26 20:07:09 2018
@@ -720,13 +720,9 @@ class Configuration(object):
enable_fs = self.get_lit_bool('enable_filesystem', default=False)
if not enable_fs:
return
- enable_experimental = self.get_lit_bool('enable_experimental', default=False)
- if not enable_experimental:
- self.lit_config.fatal(
- 'filesystem is enabled but libc++experimental.a is not.')
self.config.available_features.add('c++filesystem')
static_env = os.path.join(self.libcxx_src_root, 'test', 'std',
- 'experimental', 'filesystem', 'Inputs', 'static_test_env')
+ 'input.output', 'filesystems', 'Inputs', 'static_test_env')
static_env = os.path.realpath(static_env)
assert os.path.isdir(static_env)
self.cxx.compile_flags += ['-DLIBCXX_FILESYSTEM_STATIC_TEST_ROOT="%s"' % static_env]
@@ -821,6 +817,10 @@ class Configuration(object):
if libcxx_experimental:
self.config.available_features.add('c++experimental')
self.cxx.link_flags += ['-lc++experimental']
+ libcxx_fs = self.get_lit_bool('enable_filesystem', default=False)
+ if libcxx_fs:
+ self.config.available_features.add('c++fs')
+ self.cxx.link_flags += ['-lc++fs']
if self.link_shared:
self.cxx.link_flags += ['-lc++']
else:
Modified: libcxx/trunk/www/cxx1z_status.html
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/www/cxx1z_status.html?rev=338093&r1=338092&r2=338093&view=diff
==============================================================================
--- libcxx/trunk/www/cxx1z_status.html (original)
+++ libcxx/trunk/www/cxx1z_status.html Thu Jul 26 20:07:09 2018
@@ -83,7 +83,7 @@
<tr><td></td><td></td><td></td><td></td><td></td><td></td></tr>
<tr><td><a href="https://wg21.link/P0024R2">P0024R2</a></td><td>LWG</td><td>The Parallelism TS Should be Standardized</td><td>Jacksonville</td><td></td><td></td></tr>
<tr><td><a href="https://wg21.link/P0226R1">P0226R1</a></td><td>LWG</td><td>Mathematical Special Functions for C++17</td><td>Jacksonville</td><td></td><td></td></tr>
- <tr><td><a href="https://wg21.link/P0220R1">P0220R1</a></td><td>LWG</td><td>Adopt Library Fundamentals V1 TS Components for C++17</td><td>Jacksonville</td><td>In Progress</td><td></td></tr>
+ <tr><td><a href="https://wg21.link/P0220R1">P0220R1</a></td><td>LWG</td><td>Adopt Library Fundamentals V1 TS Components for C++17</td><td>Jacksonville</td><td>Complete</td><td>7.0</td></tr>
<tr><td><a href="https://wg21.link/P0218R1">P0218R1</a></td><td>LWG</td><td>Adopt the File System TS for C++17</td><td>Jacksonville</td><td>In Progress</td><td></td></tr>
<tr><td><a href="https://wg21.link/P0033R1">P0033R1</a></td><td>LWG</td><td>Re-enabling shared_from_this</td><td>Jacksonville</td><td>Complete</td><td>3.9</td></tr>
<tr><td><a href="https://wg21.link/P0005R4">P0005R4</a></td><td>LWG</td><td>Adopt not_fn from Library Fundamentals 2 for C++17</td><td>Jacksonville</td><td>Complete</td><td>3.9</td></tr>
@@ -443,7 +443,7 @@
<tr><td><a href="https://wg21.link/LWG2778">2778</a></td><td>basic_string_view is missing constexpr</td><td>Issaquah</td><td>Complete</td></tr>
<tr><td></td><td></td><td></td><td></td></tr>
<tr><td><a href="https://wg21.link/LWG2260">2260</a></td><td>Missing requirement for Allocator::pointer</td><td>Kona</td><td></td></tr>
- <tr><td><a href="https://wg21.link/LWG2676">2676</a></td><td>Provide filesystem::path overloads for File-based streams</td><td>Kona</td><td></td></tr>
+ <tr><td><a href="https://wg21.link/LWG2676">2676</a></td><td>Provide filesystem::path overloads for File-based streams</td><td>Kona</td><td>Complete</td></tr>
<tr><td><a href="https://wg21.link/LWG2768">2768</a></td><td>any_cast and move semantics</td><td>Kona</td><td>Complete</td></tr>
<tr><td><a href="https://wg21.link/LWG2769">2769</a></td><td>Redundant const in the return type of any_cast(const any&)</td><td>Kona</td><td>Complete</td></tr>
<tr><td><a href="https://wg21.link/LWG2781">2781</a></td><td>Contradictory requirements for std::function and std::reference_wrapper</td><td>Kona</td><td>Complete</td></tr>
More information about the cfe-commits
mailing list
--- libcxx/trunk/test/std/experimental/filesystem/class.path/path.member/path.assign/braced_init.pass.cpp (original)
+++ libcxx/trunk/test/std/input.output/filesystems/fs.req.namespace/namespace.pass.cpp Thu Jul 26 20:07:09 2018
@@ -7,25 +7,20 @@
//
//===----------------------------------------------------------------------===//
-// UNSUPPORTED: c++98, c++03
+// UNSUPPORTED: c++98, c++03, c++11, c++14
-// <experimental/filesystem>
+// <filesystem>
-// class path
+// namespace std::filesystem
-// path& operator=(path const&);
-
-#include "filesystem_include.hpp"
+#include <filesystem>
#include <type_traits>
-#include <cassert>
-
-#include "test_macros.h"
-#include "count_new.hpp"
+using namespace std::filesystem;
int main() {
- using namespace fs;
- path p("abc");
- p = {};
- assert(p.native() == "");
+ static_assert(std::is_same<
+ path,
+ std::filesystem::path
+ >::value, "");
}
Copied: libcxx/trunk/test/std/input.output/filesystems/lit.local.cfg (from r338006, libcxx/trunk/test/libcxx/experimental/filesystem/lit.local.cfg)
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/std/input.output/filesystems/lit.local.cfg?p2=libcxx/trunk/test/std/input.output/filesystems/lit.local.cfg&p1=libcxx/trunk/test/libcxx/experimental/filesystem/lit.local.cfg&r1=338006&r2=338093&rev=338093&view=diff
==============================================================================
(empty)
Modified: libcxx/trunk/test/support/filesystem_include.hpp
URL: http://llvm.org/viewvc/llvm-project/libcxx/trunk/test/support/filesystem_include.hpp?rev=338093&r1=338092&r2=338093&view=diff
==============================================================================